@@ -2,7 +2,7 @@
 
 
 package HiD::App::Command::server;
-$HiD::App::Command::server::VERSION = '1.7';
+$HiD::App::Command::server::VERSION = '1.9';
 use Moose;
 extends 'HiD::App::Command';
 with 'HiD::Role::PublishesDrafts';
@@ -22,6 +22,10 @@ use Class::Load      qw/ :all /;
 use Plack::Builder;
 use Plack::Runner;
 
+use HiD::Server;
+use HiD::Server::Handler;
+use HiD::Server::Loader;
+
 
 has auto_refresh => (
   is            => 'ro',
@@ -81,31 +85,8 @@ sub _run {
     $config->{publish_drafts} = 1;
   }
 
-  $self->publish;
-
   my $app = HiD::Server->new( root => $self->destination )->to_app;
 
-  my %args = ( -p => $self->port );
-
-  # auto refresh
-  if ( $self->auto_refresh ) {
-    my @dirs = map { $self->hid->get_config($_) } qw/ include_dir layout_dir posts_dir /;
-
-    for my $dir (qw/pages regular_files/) {
-      push @dirs, map { $_->input_filename } @{ $self->hid->$dir };
-    }
-
-    $args{'-R'} = join ',', @dirs;
-    $args{'-r'} = 1;
-
-    my $original_app = $app;
-    $app = \sub {
-      say 'Rebuild ... ';
-      $self->publish;
-      $original_app;
-    };
-  }
-
   if ( $self->debug ) {
     if ( try_load_class( 'Plack::Middleware::DebugLogging' )) {
       $app = builder {
@@ -120,42 +101,40 @@ sub _run {
   }
 
   my $runner = Plack::Runner->new;
+  my %args   = ( '-p' => $self->port );
   $runner->parse_options(%args);
+
+  # auto refresh
+  if ( $self->auto_refresh ) {
+    my @dirs = map { $self->hid->get_config($_) } qw/ include_dir layout_dir posts_dir /;
+
+    for my $dir (qw/pages regular_files/) {
+      push @dirs, map { $_->input_filename } @{ $self->hid->$dir };
+    }
+
+    # FIXME wish there was a better way to override stuff in Plack::Runner. >_<
+    $runner->{server} = '+HiD::Server::Handler';
+    $runner->{loader} = '+HiD::Server::Loader';
+    $runner->loader->watch(@dirs);
+
+    push @{$runner->{options}} , ( hid => $self );
+
+    # no need to explicitly ->publish() here, as that will happen inside
+    # HiD::Server::Loader, in the child, after the fork.
+  }
+  else { $self->publish() }
+
   $runner->run($app);
 }
 
 __PACKAGE__->meta->make_immutable;
-
-package # hide...
-  HiD::Server;
-
-use parent 'Plack::App::File';
-
-sub locate_file  {
-  my ($self, $env) = @_;
-
-  my $path = $env->{PATH_INFO} || '';
-
-  $path =~ s|^/|| unless $path eq '/';
-
-  if ( -e -d $path and $path !~ m|/$| ) {
-    $path .= '/';
-    $env->{PATH_INFO} .= '/';
-  }
-
-  $env->{PATH_INFO} .= 'index.html'
-    if ( $path && $path =~ m|/$| );
-
-  return $self->SUPER::locate_file( $env );
-}
-
 1;
 
 __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -176,6 +155,9 @@ Start a Plack-based web server that serves your C<destination> directory.
 
 Automatically refresh result when source file/dir changed, just likey jekyll
 
+Note that setting this will also clean out the destination directory whenever
+a watched file changes.
+
 =head2 clean
 
 Remove any existing site directory prior to the publication run
@@ -195,7 +177,7 @@ sub commands.
 
 =head1 VERSION
 
-version 1.7
+version 1.9
 
 =head1 AUTHOR
 
@@ -203,7 +185,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
