@@ -2,14 +2,17 @@
 
 
 package HiD::Generator::ArchivePage;
-$HiD::Generator::ArchivePage::VERSION = '1.95_92';
+$HiD::Generator::ArchivePage::VERSION = '1.9';
 use Moose;
 with 'HiD::Generator';
 
-use 5.014; # strict, unicode_strings
-
 use HiD::Page;
 
+has 'destination' => (
+  is      => 'ro' ,
+  isa     => 'HiD_DirPath' ,
+);
+
 
 sub generate {
   my( $self , $site ) = @_;
@@ -21,9 +24,8 @@ sub generate {
 
   my $url = $site->config->{archive_page}{url} // 'archive/';
 
-  my $destination = $site->config->{archive_page}{destination} // $site->destination;
-
-  $self->_create_destination_directory_if_needed( $destination );
+  ### FIXME
+  my $destination = $self->destination // $site->destination;
 
   my %archive = (
     by_year       => {} ,
@@ -75,8 +77,7 @@ This Generator produces an archive page of all your posts.
 Enable it by setting the 'archive_page.generate' key in your config to true
 and the 'archive_page.layout' key to the path with the layout for the archive
 page. You can also set 'archive_page.url' to the URL where the page should be
-published to, or let it default to the site-wide destination. Finally,
-'archive_page.destination' can be used to set a destination directory.
+published to, or let it default to 'archive/'.
 
 =head1 METHODS
 
@@ -84,7 +85,7 @@ published to, or let it default to the site-wide destination. Finally,
 
 =head1 VERSION
 
-version 1.95_92
+version 1.9
 
 =head1 AUTHOR
 
