@@ -2,7 +2,7 @@
 
 
 package HiD::Generator::AtomFeed;
-$HiD::Generator::AtomFeed::VERSION = '1.7';
+$HiD::Generator::AtomFeed::VERSION = '1.9';
 use Moose;
 with 'HiD::Generator';
 
@@ -107,7 +107,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -121,7 +121,7 @@ Enable it by setting the 'atom_feed' key in your config to the path where the
 feed should be generated.
 
 The 'atom_feed_base' and 'atom_feed_link' keys, if they exist, will be used to
-add the 'rel=altertate' base link and the 'rel=self' feed link to the atom
+add the 'rel=alternate' base link and the 'rel=self' feed link to the atom
 feed, respectively.
 
 =head1 METHODS
@@ -130,7 +130,7 @@ feed, respectively.
 
 =head1 VERSION
 
-version 1.7
+version 1.9
 
 =head1 AUTHOR
 
@@ -138,7 +138,7 @@ John SJ Anderson <genehack@genehack.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by John SJ Anderson.
+This software is copyright (c) 2015 by John SJ Anderson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
