@@ -2,8 +2,8 @@
 
 
 package HiD::Server::Loader;
-$HiD::Server::Loader::VERSION = '1.95_92';
-use 5.014;  # strict, unicode_strings
+$HiD::Server::Loader::VERSION = '1.9';
+use strict;
 use warnings;
 
 use parent 'Plack::Loader::Restarter';
@@ -47,7 +47,7 @@ Another helper for C<hid publish -A>
 
 =head1 VERSION
 
-version 1.95_92
+version 1.9
 
 =head1 AUTHOR
 
